@@ -72,6 +72,24 @@ class DisableFastSnapshotRestoreSuccessItem {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>The ID of the Availability Zone.</p>
+   */
+  inline const Aws::String& GetAvailabilityZoneId() const { return m_availabilityZoneId; }
+  inline bool AvailabilityZoneIdHasBeenSet() const { return m_availabilityZoneIdHasBeenSet; }
+  template <typename AvailabilityZoneIdT = Aws::String>
+  void SetAvailabilityZoneId(AvailabilityZoneIdT&& value) {
+    m_availabilityZoneIdHasBeenSet = true;
+    m_availabilityZoneId = std::forward<AvailabilityZoneIdT>(value);
+  }
+  template <typename AvailabilityZoneIdT = Aws::String>
+  DisableFastSnapshotRestoreSuccessItem& WithAvailabilityZoneId(AvailabilityZoneIdT&& value) {
+    SetAvailabilityZoneId(std::forward<AvailabilityZoneIdT>(value));
+    return *this;
+  }
+  ///@}
+
   ///@{
   /**
    * <p>The state of fast snapshot restores for the snapshot.</p>
@@ -250,6 +268,9 @@ class DisableFastSnapshotRestoreSuccessItem {
   Aws::String m_availabilityZone;
   bool m_availabilityZoneHasBeenSet = false;
 
+  Aws::String m_availabilityZoneId;
+  bool m_availabilityZoneIdHasBeenSet = false;
+
   FastSnapshotRestoreStateCode m_state{FastSnapshotRestoreStateCode::NOT_SET};
   bool m_stateHasBeenSet = false;
 
