@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class IpamPublicAddressAssociationStatus
-  {
-    NOT_SET,
-    associated,
-    disassociated
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class IpamPublicAddressAssociationStatus { NOT_SET, associated, disassociated };
 
-namespace IpamPublicAddressAssociationStatusMapper
-{
+namespace IpamPublicAddressAssociationStatusMapper {
 AWS_EC2_API IpamPublicAddressAssociationStatus GetIpamPublicAddressAssociationStatusForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForIpamPublicAddressAssociationStatus(IpamPublicAddressAssociationStatus value);
-} // namespace IpamPublicAddressAssociationStatusMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace IpamPublicAddressAssociationStatusMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
